

			import * as THREE from '../build/three.module.js';

			import { OrbitControls } from './jsm/controls/OrbitControls.js';
			import { SVGLoader } from './jsm/loaders/SVGLoader.js';

			var camera, scene, renderer;

			init();
			animate();

			function init( ) {

				camera = new THREE.PerspectiveCamera( 45, window.innerWidth / window.innerHeight, 1, 10000 );
				camera.position.set( 0, - 400, 600 );

				scene = new THREE.Scene();
				scene.background = new THREE.Color( 0xf0f0f0 );

				var loader = new THREE.FontLoader();
				loader.load( 'fonts/helvetiker_regular.typeface.json', function ( font ) {

					var xMid, text;

					var color = new THREE.Color( 0x006699 );

					var matDark = new THREE.MeshBasicMaterial( {
						color: color,
						side: THREE.DoubleSide
					} );

					var matLite = new THREE.MeshBasicMaterial( {
						color: color,
						transparent: true,
						opacity: 0.4,
						side: THREE.DoubleSide
					} );

					var message = "   Three.js\nStroke text.";

					var shapes = font.generateShapes( message, 100 );

					var geometry = new THREE.ShapeBufferGeometry( shapes );

					geometry.computeBoundingBox();

					xMid = - 0.5 * ( geometry.boundingBox.max.x - geometry.boundingBox.min.x );

					geometry.translate( xMid, 0, 0 );

					// make shape ( N.B. edge view not visible )

					text = new THREE.Mesh( geometry, matLite );
					text.position.z = - 150;
					scene.add( text );

					// make line shape ( N.B. edge view remains visible )

					var holeShapes = [];

					for ( var i = 0; i < shapes.length; i ++ ) {

						var shape = shapes[ i ];

						if ( shape.holes && shape.holes.length > 0 ) {

							for ( var j = 0; j < shape.holes.length; j ++ ) {

								var hole = shape.holes[ j ];
								holeShapes.push( hole );

							}

						}

					}

					shapes.push.apply( shapes, holeShapes );

					var style = SVGLoader.getStrokeStyle( 5, color.getStyle() );

					var strokeText = new THREE.Group();

					for ( var i = 0; i < shapes.length; i ++ ) {

						var shape = shapes[ i ];

						var points = shape.getPoints();

						var geometry = SVGLoader.pointsToStroke( points, style );

						geometry.translate( xMid, 0, 0 );

						var strokeMesh = new THREE.Mesh( geometry, matDark );
						strokeText.add( strokeMesh );

					}

					scene.add( strokeText );

				} ); //end load function

				renderer = new THREE.WebGLRenderer( { antialias: true } );
				renderer.setPixelRatio( window.devicePixelRatio );
				renderer.setSize( window.innerWidth, window.innerHeight );
				document.body.appendChild( renderer.domElement );

				var controls = new OrbitControls( camera, renderer.domElement );
				controls.target.set( 0, 0, 0 );
				controls.update();

				window.addEventListener( 'resize', onWindowResize, false );

			} // end init

			function onWindowResize() {

				camera.aspect = window.innerWidth / window.innerHeight;
				camera.updateProjectionMatrix();

				renderer.setSize( window.innerWidth, window.innerHeight );

			}

			function animate() {

				requestAnimationFrame( animate );

				render();

			}

			function render() {

				renderer.render( scene, camera );

			}

